{% extends "base.html" %}
{% load i18n %}
{% load uni_form_tags %}

{% block main %}

<h1>{{ object.filename }}</h1>

<div class="metaline">{{ object.user.get_full_name|default:object.user }},
    <time datetime="{{ object.submit_date|date:"c" }}">{{ object.submit_date|date:"j F" }}</div>
<p>{{ object.content_type }}, {{ object.content_category }}</p>

<p><a href="{{ object.file.url }}">{{ object.file.url }}</a></p>

<p>{% if object.show %}{% trans "Published" %}{% else %}{% trans "Hidden" %}{% endif %}</p>

<div class="tagline">{% for tag in object.tags.all %}<a class="tag" href="{{ request.path_info }}/{{ tag }}">{{ tag }}</a>{% endfor %}</div>

{% endblock main %}

{% block context_menu %}
<li><a href="{% url 'media-file-edit' object.id %}">{% trans "Edit" %}</a></li>
<li><a href="{% url 'media-file-list' %}">All published files</a></li>
<li><a href="{% url 'media-file-unpublished' %}">My unpublished files</a></li>
<li><a href="{% url 'media-file-new' %}">Upload files</a></li>

{% endblock %}
