{% extends 'simple.html' %}
{% load uni_form_tags %}
{% load i18n %}

{% block title %}{% trans "Upload files" %}{% endblock %}

{% block main %}
    <h1>{% trans "Upload files" %}</h1>
    <form action="" method="post" id="uploadform" class="uniForm" enctype="multipart/form-data">
        <fieldset class="inlineLabels">
            {% csrf_token %}
            {{ form|as_uni_form }}
        </fieldset>
        <div class="buttonHolder">
            <button type="submit" id="submit">{% trans "Upload" %}</button>
        </div>
    </form>
{% endblock main %}

{% block context_menu %}
<li><a href="{% url 'media-image-list' %}">{% trans "Published files" %}</a></li>
{% endblock %}

